import webbrowser
from apiclient.discovery import build    
import os
class API:
	def __init__(self,keyword,maxlen,order='relevance',type='video'):
		self.__API_KEY=os.environ.get('API_KEY')
		#link to get the api key is in readme file
		youtube=build('youtube','v3',developerKey=self.__API_KEY)
		self.keyword=keyword
		self.maxlen=maxlen
		self.order=order
		self.type=type
		req=youtube.search().list(q=self.keyword,part='snippet',
			maxResults=self.maxlen,type=self.type,order=self.order,
			)
		self.result=req.execute() 
	def open_id(self,item_no):
		return webbrowser.open('https://www.youtube.com/watch?v='+self.result['items'][item_no]['id']['videoId'])
	def get_titles(self):
		stm=[]
		for i in range(self.maxlen):
			stm.append(self.result['items'][i]['snippet']['title'])
		return stm
	def get_descriptions(self):
		stm=[]
		for i in range(self.maxlen):
			stm.append(self.result['items'][i]['snippet']['description'])
		return stm
	def get_image_urls(self):
		stm=[]
		for i in range(self.maxlen):
			stm.append(self.result['items'][0]['snippet']['thumbnails']['medium']['url'])
		return stm
		




import click
import webbrowser
from apiclient.discovery import build
from helper import API



@click.command()
@click.option('--count', default=5, help='enter the number of video you are looking for.')
@click.option('--title',prompt='title of the video',help='enter the title name of video you are looking for')     
@click.option('--order',help='to sort the video by date rating viewCount') 
@click.option('--type',help='to search for type of video like channel video playlist')
def titles(count,title,order,type):
	obj=API(title,count,order,type)
	l=obj.get_titles()
	for j,i in enumerate(l):
		click.echo('{0} > title {1}'.format(j,i))
	vid=value = click.prompt('type id for more', type=int)
	open_link(obj,vid)


def ffcall(i,obj,vid):
	if(i==0):
		l=obj.get_descriptions()
		print(l[vid])
	if(i==1):
		obj.open_id(vid)
		

def open_link(obj,vid):
	while(1):
		print("0. get video description\n1. open video url")
		l=int(input())
		ffcall(l,obj,vid)
		

	
if __name__ == '__main__':
    titles()



import os
from setuptools import setup, find_packages

def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
    name="humdrum",
    version="0.4",
    author="Prince Roshan",
    author_email="princekrroshan01@gmail.com",
    url="https://github.com/princekrroshan01/humdrum",
    description=("A  CLI tool for youtube data api v3"),
    long_description=read('README.md'),
    license="MIT",
    py_modules=['helper','cli'],
    entry_points={'console_scripts': ['humdrum = cli:titles']},
    install_requires=['google-api-python-client', 'click'],
    include_package_data=True
)

